aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/runtime/CL/functions/CLGEMMLowpMatrixMultiplyCore.h
diff options
context:
space:
mode:
authorgiuros01 <giuseppe.rossini@arm.com>2019-01-11 14:04:43 +0000
committerGiuseppe Rossini <giuseppe.rossini@arm.com>2019-01-14 12:42:42 +0000
commit1c9efebf4344e8db97e6d9282b2bf48b52090b58 (patch)
tree40c8737a23ff289cb176618d7c16fd4b2d811689 /arm_compute/runtime/CL/functions/CLGEMMLowpMatrixMultiplyCore.h
parent685c181d5ac36948f8df22f627ef9b3a74b5f87e (diff)
downloadComputeLibrary-1c9efebf4344e8db97e6d9282b2bf48b52090b58.tar.gz
Issue COMPMID-1835: Remove CLGEMMInterleave4x4Kernel and replace with CLGEMMReshapeLHSMatrixKernel
Change-Id: Id6a1bd78f9b1698b64a004e4adebc41002b15745 Reviewed-on: https://review.mlplatform.org/496 Tested-by: Arm Jenkins <bsgcomp@arm.com> Reviewed-by: Gian Marco Iodice <gianmarco.iodice@arm.com>
Diffstat (limited to 'arm_compute/runtime/CL/functions/CLGEMMLowpMatrixMultiplyCore.h')
-rw-r--r--arm_compute/runtime/CL/functions/CLGEMMLowpMatrixMultiplyCore.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/arm_compute/runtime/CL/functions/CLGEMMLowpMatrixMultiplyCore.h b/arm_compute/runtime/CL/functions/CLGEMMLowpMatrixMultiplyCore.h
index 141354e723..72d91070f8 100644
--- a/arm_compute/runtime/CL/functions/CLGEMMLowpMatrixMultiplyCore.h
+++ b/arm_compute/runtime/CL/functions/CLGEMMLowpMatrixMultiplyCore.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2017-2018 ARM Limited.
+ * Copyright (c) 2017-2019 ARM Limited.
*
* SPDX-License-Identifier: MIT
*
@@ -24,11 +24,11 @@
#ifndef __ARM_COMPUTE_CLGEMMLOWPMATRIXMULTIPLYCORE_H__
#define __ARM_COMPUTE_CLGEMMLOWPMATRIXMULTIPLYCORE_H__
-#include "arm_compute/core/CL/kernels/CLGEMMInterleave4x4Kernel.h"
#include "arm_compute/core/CL/kernels/CLGEMMLowpMatrixMultiplyKernel.h"
#include "arm_compute/core/CL/kernels/CLGEMMLowpOffsetContributionKernel.h"
#include "arm_compute/core/CL/kernels/CLGEMMLowpOffsetContributionOutputStageKernel.h"
#include "arm_compute/core/CL/kernels/CLGEMMLowpReductionKernel.h"
+#include "arm_compute/core/CL/kernels/CLGEMMReshapeLHSMatrixKernel.h"
#include "arm_compute/core/CL/kernels/CLGEMMReshapeRHSMatrixKernel.h"
#include "arm_compute/runtime/CL/CLMemoryGroup.h"
#include "arm_compute/runtime/CL/CLTensor.h"
@@ -41,7 +41,7 @@ class ICLTensor;
/** Basic function to execute GEMMLowpMatrixMultiplyCore on OpenCL. This function calls the following OpenCL kernels:
*
* -# @ref CLGEMMInterleave4x4Kernel (if the output tensor is a matrix)
* -# @ref CLGEMMReshapeRHSMatrixKernel (if the output tensor is a matrix)
* -# @ref CLGEMMLowpMatrixMultiplyKernel
* -# @ref CLGEMMLowpMatrixAReductionKernel (if the offset of matrix B is not 0)
@@ -101,7 +101,7 @@ public:
private:
CLMemoryGroup _memory_group;
CLGEMMLowpMatrixMultiplyKernel _mm_kernel;
- CLGEMMInterleave4x4Kernel _mtx_a_reshape_kernel;
+ CLGEMMReshapeLHSMatrixKernel _mtx_a_reshape_kernel;
CLGEMMReshapeRHSMatrixKernel _mtx_b_reshape_kernel;
CLGEMMLowpMatrixAReductionKernel _mtx_a_reduction_kernel;
CLGEMMLowpMatrixBReductionKernel _mtx_b_reduction_kernel;
@@ -41,7 +41,7 @@ class ICLTensor;
/** Basic function to execute GEMMLowpMatrixMultiplyCore on OpenCL. This function calls the following OpenCL kernels:
*
- * -# @ref CLGEMMInterleave4x4Kernel (if the output tensor is a matrix)
+ * -# @ref CLGEMMReshapeLHSMatrixKernel (if the output tensor is a matrix)
* -# @ref CLGEMMReshapeRHSMatrixKernel (if the output tensor is a matrix)
* -# @ref CLGEMMLowpMatrixMultiplyKernel